@@ -1,3 +1,4 @@
+from dateutil.tz import tzlocal
 import stream
 import time
 from stream.exceptions import ApiKeyException, InputException,\
@@ -6,6 +7,8 @@ import random
 from unittest.case import TestCase
 
 import os
+import datetime
+from stream import serializer
 
 def connect_debug():
     return stream.connect(
@@ -148,12 +151,52 @@ class ClientTest(TestCase):
         self.assertRaises(ApiKeyException, lambda:
                           self.user1.add_activity(activity_data))
 
-    def test_missing_field_exception(self):
-        activity_data = {'actor': 1, 'verb': 'tweet',
-                         'object': 1, 'debug_example_undefined': 'test'}
-        self.assertRaises(CustomFieldException, lambda:
-                          self.user1.add_activity(activity_data))
+    def test_complex_field(self):
+        activity_data = {'actor': 1, 'verb': 'tweet', 'object': 1, 'participants': ['Tommaso', 'Thierry']}
+        response = self.user1.add_activity(activity_data)
+        activity_id = response['id']
+        activities = self.user1.get(limit=1)['results']
+        self.assertEqual(activities[0]['id'], activity_id)
+        self.assertEqual(activities[0]['participants'], ['Tommaso', 'Thierry'])
+        
+    def assertDatetimeAlmostEqual(self, a, b):
+        difference = abs(a-b)
+        if difference > datetime.timedelta(milliseconds=1):
+            self.assertEqual(a, b)
 
+    def assertClearlyNotEqual(self, a, b):
+        difference = abs(a-b)
+        if difference < datetime.timedelta(milliseconds=1):
+            raise ValueError('the dates are too close')
+        
+    def test_uniqueness(self):
+        '''
+        In order for things to be considere unique they need:
+        a.) The same time and activity data
+        b.) The same time and foreign id
+        '''
+        now = datetime.datetime.now(tzlocal())
+        utcnow = datetime.datetime.utcnow()
+        activity_data = {'actor': 1, 'verb': 'tweet', 'object': 1, 'time': now}
+        response = self.user1.add_activity(activity_data)
+        response = self.user1.add_activity(activity_data)
+        activities = self.user1.get(limit=2)['results']
+        self.assertDatetimeAlmostEqual(activities[0]['time'], utcnow)
+        self.assertClearlyNotEqual(activities[1]['time'], utcnow)
+        
+    def test_uniqueness_foreign_id(self):
+        now = datetime.datetime.now(tzlocal())
+        utcnow = datetime.datetime.utcnow()
+        activity_data = {'actor': 1, 'verb': 'tweet', 'object': 1, 'foreign_id': 'tweet:11', 'time': now}
+        response = self.user1.add_activity(activity_data)
+        activity_data = {'actor': 2, 'verb': 'tweet', 'object': 3, 'foreign_id': 'tweet:11', 'time': now}
+        response = self.user1.add_activity(activity_data)
+        activities = self.user1.get(limit=2)['results']
+        # the second post should have overwritten the first one (because they had same id)
+        self.assertEqual(activities[0]['object'], '3')
+        self.assertEqual(activities[0]['foreign_id'], 'tweet:11')
+        self.assertDatetimeAlmostEqual(activities[0]['time'], utcnow)
+        
     def test_missing_actor(self):
         activity_data = {'verb': 'tweet', 'object':
                          1, 'debug_example_undefined': 'test'}
@@ -170,3 +213,14 @@ class ClientTest(TestCase):
             'tfq2sdqpj9g446sbv653x3aqmgn33hsn8uzdc9jpskaw8mj6vsnhzswuwptuj9su'
         )
         self.assertRaises(ValueError, lambda: self.c.feed('user1'))
+        
+    def test_serialization(self):
+        today = datetime.date.today()
+        now = datetime.datetime.now()
+        data = dict(string='string', float=0.1, int=1, date=today, datetime=now)
+        serialized = serializer.dumps(data)
+        loaded = serializer.loads(serialized)
+        self.assertEqual(data, loaded)
+        
+        
+        
